@@ -33,6 +33,12 @@ use std::io;
 /// Default compression level.
 pub use zstd_safe::CLEVEL_DEFAULT as DEFAULT_COMPRESSION_LEVEL;
 
+/// The accepted range of compression levels.
+pub fn compression_level_range(
+) -> std::ops::RangeInclusive<zstd_safe::CompressionLevel> {
+    zstd_safe::min_c_level()..=zstd_safe::max_c_level()
+}
+
 #[doc(no_inline)]
 pub use crate::stream::{decode_all, encode_all, Decoder, Encoder};
 
@@ -63,3 +69,8 @@ where
 {
     test_cycle(data, |data| f(data).unwrap(), |data| g(data).unwrap())
 }
+
+#[test]
+fn default_compression_level_in_range() {
+    assert!(compression_level_range().contains(&DEFAULT_COMPRESSION_LEVEL));
+}
